$configFile = ".\appsettings.Production.json"
if ((Test-Path $configFile))
{
    Write-Output "Reading from" $configFile
    $data = Get-Content $configFile -Raw -Encoding UTF8
    $data = [regex]::Replace($data,"\/\/<!--(.*)\n","")
    $appSettingsJson = $data | ConvertFrom-Json
}
else
{
    Write-Output $configFile " will be created"
    $appSettingsJson = New-Object -TypeName PSObject
}

if (-not $appsettingsJson.PSobject.Properties['Authentication'])
{
    $appSettingsJson | Add-Member -Name 'Authentication' -MemberType NoteProperty -Value ([PSCustomObject]@{ BuiltInJwtBearer = [PSCustomObject]@{ SecurityKey = ''}})
}
elseif (-not $appsettingsJson.Authentication.PSobject.Properties['BuiltInJwtBearer'])
{
    $appSettingsJson.Authentication | Add-Member -Name 'BuiltInJwtBearer' -MemberType NoteProperty  -Value ([PSCustomObject]@{ SecurityKey = ''})
}
elseif (-not $appsettingsJson.Authentication.BuiltInJwtBearer.PSobject.Properties['SecurityKey'])
{
    $appSettingsJson.Authentication.BuiltInJwtBearer | Add-Member -Name 'SecurityKey' -MemberType NoteProperty -Value ''
}

$randomKey = -join ((48..57) + (65..90) + (97..122) | Get-Random -Count 32 | ForEach-Object {[char]$_})
if ([string]::IsNullOrEmpty($appSettingsJson.Authentication.BuiltInJwtBearer.SecurityKey))
{
    $appSettingsJson.Authentication.BuiltInJwtBearer.SecurityKey = $randomKey
    $appSettingsJson | ConvertTo-Json -Depth 100 | Out-File .\appsettings.Production.json  -Encoding UTF8
    Write-Output "SecurityKey is set"
}
else
{
    Write-Warning "SecurityKey already exists"
}